@@ -459,7 +459,8 @@ class Database(object):
                 ('ora', 'TIMESTAMP(6)', 'ora', 'create'): '{column} date',
                 ('ora', 'TIMESTAMP(6)', 'ora', 'query'): column,
                 ('ora', 'NUMBER', 'my', 'create'):
-                    '{column} double' if scale
+                    '{column} decimal' if column.upper() == "GMA_IND_CMPLX"
+                    else '{column} double' if scale
                     else '{column} int' if not precision or precision < 10
                     else '{column} bigint',
                 ('ora', 'NUMBER', 'my', 'query'): column,
